delu.hardware
=============

.. currentmodule:: delu.hardware

.. automodule:: delu.hardware

----

.. rubric:: Deprecated items

.. raw:: html

   <details>
   <summary>Show</summary>

.. autosummary::
    :nosignatures:
    :toctree: api

    free_memory
    get_gpus_info

.. raw:: html

   </details>
